@@ -1,3 +1,4 @@
+import sys
 from ansibler.args.cmd import get_user_arguments
 from ansibler.compatibility.chart import generate_compatibility_chart
 from ansibler.platforms.populate import populate_platforms
@@ -23,13 +24,17 @@ def run_ansibler() -> None:
         clear_cache()
         print("Cache cleared")
 
+    inline_replace = args.get("inline-replace", False)
+
     # Run generate compatibility charts
     if "generate-compatibility-chart" in args:
-        generate_compatibility_chart()
+        molecule_results_dir = args.get("molecule-results-dir")
+        generate_compatibility_chart(
+            molecule_results_dir, inline_replace=inline_replace)
     elif "populate-platforms" in args:
-        populate_platforms()
+        populate_platforms(inline_replace=inline_replace)
     elif "role-dependencies" in args:
-        generate_role_dependency_chart()
+        generate_role_dependency_chart(inline_replace=inline_replace)
     else:
         display_help()
 
